@@ -12,9 +12,6 @@
 
 LineEditWithAutocorrectionTest::LineEditWithAutocorrectionTest()
 {
-    if (qEnvironmentVariableIntValue("KDECI_CANNOT_CREATE_WINDOWS")) {
-        QSKIP("KDE CI can't create a window on this platform, skipping some gui tests");
-    }
 }
 
 void LineEditWithAutocorrectionTest::shouldNotAutocorrectWhenDisabled()
