@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -32,9 +32,9 @@ bool PimCommon::PluginUtil::isPluginActivated(const QStringList &enabledPluginsL
     return false;
 }
 
-QPair<QStringList, QStringList> PimCommon::PluginUtil::loadPluginSetting(const QString &groupName, const QString &prefixSettingKey)
+PimCommon::PluginUtil::PluginsStateList PimCommon::PluginUtil::loadPluginSetting(const QString &groupName, const QString &prefixSettingKey)
 {
-    QPair<QStringList, QStringList> pair;
+    PluginUtil::PluginsStateList pair;
     KSharedConfigPtr config = KSharedConfig::openConfig(pluginConfigFile());
     QStringList enabledPlugins;
     QStringList disabledPlugins;
@@ -44,8 +44,8 @@ QPair<QStringList, QStringList> PimCommon::PluginUtil::loadPluginSetting(const Q
         disabledPlugins = grp.readEntry(QStringLiteral("%1Disabled").arg(prefixSettingKey), QStringList());
     }
 
-    pair.first = enabledPlugins;
-    pair.second = disabledPlugins;
+    pair.enabledPluginList = enabledPlugins;
+    pair.disabledPluginList = disabledPlugins;
     return pair;
 }
 
@@ -56,8 +56,16 @@ void PimCommon::PluginUtil::savePluginSettings(const QString &groupName,
 {
     KSharedConfigPtr config = KSharedConfig::openConfig(pluginConfigFile());
     KConfigGroup grp = config->group(groupName);
-    grp.writeEntry(QStringLiteral("%1Enabled").arg(prefixSettingKey), enabledPluginsList);
-    grp.writeEntry(QStringLiteral("%1Disabled").arg(prefixSettingKey), disabledPluginsList);
+    if (enabledPluginsList.isEmpty()) {
+        grp.deleteEntry(QStringLiteral("%1Enabled").arg(prefixSettingKey));
+    } else {
+        grp.writeEntry(QStringLiteral("%1Enabled").arg(prefixSettingKey), enabledPluginsList);
+    }
+    if (disabledPluginsList.isEmpty()) {
+        grp.deleteEntry(QStringLiteral("%1Disabled").arg(prefixSettingKey));
+    } else {
+        grp.writeEntry(QStringLiteral("%1Disabled").arg(prefixSettingKey), disabledPluginsList);
+    }
 }
 
 PimCommon::PluginUtilData PimCommon::PluginUtil::createPluginMetaData(const KPluginMetaData &metaData)
