@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -202,7 +202,9 @@ QUrl ShareServiceUrlManager::generateServiceUrl(const QString &link, const QStri
 void ShareServiceUrlManager::openUrl(const QUrl &url)
 {
     if (url.isValid()) {
-        QDesktopServices::openUrl(url);
+        if (!QDesktopServices::openUrl(url)) {
+            qCWarning(PIMCOMMON_LOG) << "Impossible to open url: " << url;
+        }
     } else {
         qCDebug(PIMCOMMON_LOG) << "url is invalid.";
     }
