@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -22,6 +22,11 @@ namespace Akonadi
 class ContactGroupSearchJob;
 }
 
+namespace KLDAPCore
+{
+class LdapActivitiesAbstract;
+}
+
 namespace PimCommon
 {
 class AddresseeLineEdit;
@@ -103,6 +108,9 @@ public:
     [[nodiscard]] bool canDeleteLineEdit() const;
     void setCanDeleteLineEdit(bool inprogressToConfigureCompletion);
 
+    void setLdapActivitiesAbstract(KLDAPCore::LdapActivitiesAbstract *ldapActivities);
+    [[nodiscard]] KLDAPCore::LdapActivitiesAbstract *ldapActivitiesAbstract() const;
+
 public Q_SLOTS:
     void slotToggleExpandGroups(bool);
     void slotShowOUChanged(bool);
@@ -113,7 +121,6 @@ private:
     void slotReturnPressed(const QString &);
     void slotStartLDAPLookup();
     void slotLDAPSearchData(const KLDAPCore::LdapResult::List &);
-    void slotEditCompletionOrder();
     void slotUserCancelled(const QString &);
     void slotAkonadiHandleItems(const Akonadi::Item::List &items);
     void slotAkonadiSearchResult(KJob *);
@@ -122,6 +129,7 @@ private:
     void slotTriggerDelayedQueries();
 
     AddresseeLineEdit *const q;
+    KLDAPCore::LdapActivitiesAbstract *mLdapActivities = nullptr;
     QToolButton *mToolButton = nullptr;
     QTimer *const mDelayedQueryTimer;
     QString mPreviousAddresses;
