@@ -1,12 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2015-2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "addresseelineeditmanager.h"
 #include "addresseelineeditakonadi.h"
-#include "addresseelineeditbaloo.h"
+#include "addresseelineeditakonadisearch.h"
 #include "addresseelineeditldap.h"
 #include "kmailcompletion.h"
 
@@ -27,7 +27,7 @@ AddresseeLineEditManager::AddresseeLineEditManager()
     : mCompletion(new KMailCompletion)
     , mAddresseeLineEditAkonadi(new AddresseeLineEditAkonadi)
     , mAddressessLineEditLdap(new AddresseeLineEditLdap(this))
-    , mAddressessLineEditBaloo(new AddresseeLineEditBaloo)
+    , mAddressessLineEditBaloo(new AddresseeLineEditAkonadiSearch)
 {
     KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("AddressLineEdit"));
     mShowOU = group.readEntry("ShowOU", false);
@@ -54,6 +54,11 @@ void AddresseeLineEditManager::updateCompletionOrder()
     updateCollectionWeights();
 }
 
+void AddresseeLineEditManager::setLdapActivitiesAbstract(KLDAPCore::LdapActivitiesAbstract *ldapActivities)
+{
+    mAddressessLineEditLdap->setLdapActivitiesAbstract(ldapActivities);
+}
+
 void AddresseeLineEditManager::updateCollectionWeights()
 {
     akonadiCollectionToCompletionSourceMap.clear();
@@ -144,12 +149,12 @@ bool AddresseeLineEditManager::isLdapClientToCompletionSourceMapContains(int val
 
 int AddresseeLineEditManager::balooCompletionSource() const
 {
-    return mAddressessLineEditBaloo->balooCompletionSource();
+    return mAddressessLineEditBaloo->akonadiSearchCompletionSource();
 }
 
 void AddresseeLineEditManager::setBalooCompletionSource(int value)
 {
-    mAddressessLineEditBaloo->setBalooCompletionSource(value);
+    mAddressessLineEditBaloo->setAkonadiSearchCompletionSource(value);
 }
 
 void AddresseeLineEditManager::initializeLdap()
@@ -184,7 +189,7 @@ void AddresseeLineEditManager::restartLdap(const QString &searchString, Addresse
 
 void AddresseeLineEditManager::loadBalooBlackList()
 {
-    mAddressessLineEditBaloo->loadBalooBlackList();
+    mAddressessLineEditBaloo->loadAkonadiSearchBlackList();
 }
 
 QStringList AddresseeLineEditManager::cleanupRecentAddressEmailList(const QStringList &inputList)
@@ -203,7 +208,7 @@ QStringList AddresseeLineEditManager::cleanupEmailList(const QStringList &inputL
 
 QStringList AddresseeLineEditManager::balooBlackList() const
 {
-    return mAddressessLineEditBaloo->balooBlackList();
+    return mAddressessLineEditBaloo->akonadiSearchBlackList();
 }
 
 bool AddresseeLineEditManager::showOU() const
