@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,14 +18,18 @@
 #include <QColor>
 
 class QTimer;
-class QNetworkConfigurationManager;
+namespace KLDAPCore
+{
+class LdapActivitiesAbstract;
+}
+
 namespace PimCommon
 {
 class KMailCompletion;
 class AddresseeLineEdit;
 class AddresseeLineEditAkonadi;
 class AddresseeLineEditLdap;
-class AddresseeLineEditBaloo;
+class AddresseeLineEditAkonadiSearch;
 class AddresseeLineEditManager
 {
 public:
@@ -55,8 +59,6 @@ public:
     // holds the cached mapping from akonadi collection id to the completion source index
     struct collectionInfo {
         collectionInfo()
-            : index(-1)
-            , enabled(true)
         {
         }
 
@@ -66,8 +68,8 @@ public:
         {
         }
 
-        int index;
-        bool enabled;
+        int index = -1;
+        bool enabled = true;
     };
 
     QMap<Akonadi::Collection::Id, collectionInfo> akonadiCollectionToCompletionSourceMap;
@@ -114,6 +116,8 @@ public:
 
     [[nodiscard]] QStringList cleanupRecentAddressEmailList(const QStringList &inputList);
 
+    void setLdapActivitiesAbstract(KLDAPCore::LdapActivitiesAbstract *ldapActivities);
+
 private:
     QStringList mRecentAddressEmailList;
     QStringList mRecentCleanupAddressEmailList;
@@ -123,6 +127,6 @@ private:
     KMailCompletion *const mCompletion;
     AddresseeLineEditAkonadi *const mAddresseeLineEditAkonadi;
     AddresseeLineEditLdap *const mAddressessLineEditLdap;
-    AddresseeLineEditBaloo *const mAddressessLineEditBaloo;
+    AddresseeLineEditAkonadiSearch *const mAddressessLineEditBaloo;
 };
 }
